# -*- coding: utf-8; -*-
################################################################################
#
#  WuttaMess -- Fabric Automation Helpers
#  Copyright © 2024 Lance Edgar
#
#  This file is part of Wutta Framework.
#
#  Wutta Framework is free software: you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the Free
#  Software Foundation, either version 3 of the License, or (at your option) any
#  later version.
#
#  Wutta Framework is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
#  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
#  more details.
#
#  You should have received a copy of the GNU General Public License along with
#  Wutta Framework.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Postfix mail service
"""


def set_config(c, setting, value):
    """
    Configure the given setting with the given value.
    """
    c.run(f"postconf -e '{setting}={value}'")


def set_myhostname(c, hostname):
    """
    Configure the ``myhostname`` setting with the given string.
    """
    set_config(c, 'myhostname', hostname)


def set_myorigin(c, origin):
    """
    Configure the ``myorigin`` setting with the given string.
    """
    set_config(c, 'myorigin', origin)


def set_mydestination(c, *destinations):
    """
    Configure the ``mydestinations`` setting with the given strings.
    """
    set_config(c, 'mydestination', ', '.join(destinations))


def set_mynetworks(c, *networks):
    """
    Configure the ``mynetworks`` setting with the given strings.
    """
    set_config(c, 'mynetworks', ' '.join(networks))


def set_relayhost(c, relayhost):
    """
    Configure the ``relayhost`` setting with the given string
    """
    set_config(c, 'relayhost', relayhost)
